fnss.netconfig.capacities.clear_capacities — FNSS 0.3.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.3.2 documentation »
- API Reference »
- Functions »

# fnss.netconfig.capacities.clear_capacities

`clear_capacities`(topology)

  Remove all capacities from the topology.

  Parameters : | topology : Topology

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.3.2 documentation »
- API Reference »
- Functions »